<?php

/**
 * @file
 * Contains a fake database post-update function for testing.
 */

/**
 * Here is a fake post-update hook.
 */
function package_manager_post_update_test(): void {
}
